==> tencentcloud-sdk-java-3.1.57-sources.jar: com/tencentcloudapi/vod/v20180717/models/AiReviewProhibitedAsrTaskInput.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vod.v20180717.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AiReviewProhibitedAsrTaskInput extends AbstractModel{

    /**
    * 鉴违禁模板 ID。
    */
    @SerializedName("Definition")
    @Expose
    private Long Definition;

    /**
     * Get 鉴违禁模板 ID。 
     * @return Definition 鉴违禁模板 ID。
     */
    public Long getDefinition() {
        return this.Definition;
    }

    /**
     * Set 鉴违禁模板 ID。
     * @param Definition 鉴违禁模板 ID。
     */
    public void setDefinition(Long Definition) {
        this.Definition = Definition;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Definition", this.Definition);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/vod/v20180717/models/AiReviewProhibitedAsrTaskInput.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vod.v20180717.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AiReviewProhibitedAsrTaskInput extends AbstractModel{

    /**
    * 鉴违禁模板 ID。
    */
    @SerializedName("Definition")
    @Expose
    private Long Definition;

    /**
     * Get 鉴违禁模板 ID。 
     * @return Definition 鉴违禁模板 ID。
     */
    public Long getDefinition() {
        return this.Definition;
    }

    /**
     * Set 鉴违禁模板 ID。
     * @param Definition 鉴违禁模板 ID。
     */
    public void setDefinition(Long Definition) {
        this.Definition = Definition;
    }

    public AiReviewProhibitedAsrTaskInput() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AiReviewProhibitedAsrTaskInput(AiReviewProhibitedAsrTaskInput source) {
        if (source.Definition != null) {
            this.Definition = new Long(source.Definition);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Definition", this.Definition);

    }
}
